CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                              Ref-indic                              C
C                                                                     C
C                        Refinement indicators                        C
C                                                                     C
C               EPI Pomdapi, INRIA Paris - Rocquencourt               C
C                                                                     C
C  Copyright 2013-2014 INRIA.                                         C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

C     $Id: worker_error.fpp,v 1.4 2014-03-07 23:53:28 fclement Exp $

#include "worker_constants.h"

      subroutine worker_error_initialization(s_len, sbr, len, msg)
      
      implicit none
      
C     Input arguments.
      character sbr*(*), msg*(*)
      integer s_len, len
      
      call pio_user_error_task_computation
     +     (s_len, sbr, 4, 'init', len, msg)
      
      return
      end


      subroutine worker_error_gradient_computation(s_len, sbr, len, msg)
      
      implicit none
      
C     Input arguments.
      character sbr*(*), msg*(*)
      integer s_len, len
      
      call pio_user_error_task_computation
     +     (s_len, sbr, 4, 'grad', len, msg)
      
      return
      end


      subroutine worker_error_optimization(s_len, sbr, len, msg)
      
      implicit none
      
C     Input arguments.
      character sbr*(*), msg*(*)
      integer s_len, len
      
      call pio_user_error_task_computation
     +     (s_len, sbr, 5, 'optim', len, msg)
      
      return
      end


      subroutine worker_error_finalization(s_len, sbr, len, msg)
      
      implicit none
      
C     Input arguments.
      character sbr*(*), msg*(*)
      integer s_len, len
      
      call pio_user_error_task_computation
     +     (s_len, sbr, 5, 'final', len, msg)
      
      return
      end


      subroutine worker_error_wrong_dimension(s_len, sbr, good, bad)
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer s_len, good, bad
      
      call pio_user_error_wrong_length
     +     (s_len, sbr, 9, 'dimension', good, bad)
      
      return
      end


      subroutine worker_error_wrong_size(s_len, sbr, good, bad)
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer s_len, good, bad
      
      call pio_user_error_wrong_length
     +     (s_len, sbr, 4, 'size', good, bad)
      
      return
      end


      subroutine worker_error_wrong_zone_number(s_len, sbr, good, bad)
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer s_len, good, bad
      
      call pio_user_error_wrong_length
     +     (s_len, sbr, 11, 'zone number', good, bad)
      
      return
      end


      subroutine worker_error_too_large_dimension(s_len, sbr, bad)
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer s_len, bad
      
      call pio_user_error_too_large_length
     +     (s_len, sbr, 9, 'dimension', WORKER_MAX_DIMENSION, bad)
      
      return
      end


      subroutine worker_error_too_large_size(s_len, sbr, bad)
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer s_len, bad
      
      call pio_user_error_too_large_length
     +     (s_len, sbr, 4, 'size', WORKER_MAX_SIZE, bad)
      
      return
      end


      subroutine worker_error_too_large_zone_number(s_len, sbr, bad)
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer s_len, bad
      
      call pio_user_error_too_large_length
     +     (s_len, sbr, 11, 'zone number', WORKER_MAX_ZONE_NUMBER, bad)
      
      return
      end


      subroutine worker_error_out_of_bounds_zone_number
     +     (s_len, sbr, i, j, good, bad)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer s_len, i, j, good, bad
      
      ier = PIO_USER_OUT_OF_BOUNDS_VALUE_ERROR
      
      em_len = 15 + s_len + 1 + 21 + 15 + WORKER_MAX_DIMENSION_LEN + 1
     +     + 7 + WORKER_MAX_SIZE_LEN + 19 + WORKER_MAX_ZONE_NUMBER_LEN
     +     + 1 + 17 + 14 + WORKER_MAX_ZONE_NUMBER_LEN + 2
      em_len = min(em_len, PIO_USER_MAX_ERROR_MESSAGE_LENGTH)
      
      write(error_msg, 1001) sbr(1:s_len), i, j, bad, good
      
 1001 format('fatal error in ', a, ':',
     +     ' out of bounds value:',
     +     ' for component ', WORKER_MAX_DIMENSION_FMT, ',',
     +     ' point ', WORKER_MAX_SIZE_FMT,
     +     ' is in zone number ', WORKER_MAX_ZONE_NUMBER_FMT, ',',
     +     ' which is outside',
     +     ' of range [0..', WORKER_MAX_ZONE_NUMBER_FMT, '].')
      
      return
      end
